@@ -14,5 +14,8 @@
 
 package brook
 
+var ServerHKDFInfo = []byte{0x62, 0x72, 0x6f, 0x6f, 0x6b}
+var ClientHKDFInfo = []byte{0x62, 0x72, 0x6f, 0x6f, 0x6b}
+
 func init() {
 }
